==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/kubernetes/api/model/ConfigMapListBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class ConfigMapListBuilder extends ConfigMapListFluentImpl<ConfigMapListBuilder> implements VisitableBuilder<ConfigMapList,ConfigMapListBuilder>{

    ConfigMapListFluent<?> fluent;
    Boolean validationEnabled;

    public ConfigMapListBuilder(){
            this(true);
    }
    public ConfigMapListBuilder(Boolean validationEnabled){
            this(new ConfigMapList(), validationEnabled);
    }
    public ConfigMapListBuilder(ConfigMapListFluent<?> fluent){
            this(fluent, true);
    }
    public ConfigMapListBuilder(ConfigMapListFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ConfigMapList(), validationEnabled);
    }
    public ConfigMapListBuilder(ConfigMapListFluent<?> fluent,ConfigMapList instance){
            this(fluent, instance, true);
    }
    public ConfigMapListBuilder(ConfigMapListFluent<?> fluent,ConfigMapList instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withItems(instance.getItems()); 
            fluent.withKind(instance.getKind()); 
            fluent.withMetadata(instance.getMetadata()); 
            this.validationEnabled = validationEnabled; 
    }
    public ConfigMapListBuilder(ConfigMapList instance){
            this(instance,true);
    }
    public ConfigMapListBuilder(ConfigMapList instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.validationEnabled = validationEnabled; 
    }

    public ConfigMapList build(){
            ConfigMapList buildable = new ConfigMapList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ConfigMapListBuilder that = (ConfigMapListBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-2.0.4-sources.jar: annotations/io/fabric8/kubernetes/api/model/ConfigMapListBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ConfigMapListBuilder extends ConfigMapListFluentImpl<ConfigMapListBuilder> implements VisitableBuilder<ConfigMapList,ConfigMapListBuilder>{

    ConfigMapListFluent<?> fluent;
    Boolean validationEnabled;

    public ConfigMapListBuilder(){
            this(true);
    }
    public ConfigMapListBuilder(Boolean validationEnabled){
            this(new ConfigMapList(), validationEnabled);
    }
    public ConfigMapListBuilder(ConfigMapListFluent<?> fluent){
            this(fluent, true);
    }
    public ConfigMapListBuilder(ConfigMapListFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ConfigMapList(), validationEnabled);
    }
    public ConfigMapListBuilder(ConfigMapListFluent<?> fluent,ConfigMapList instance){
            this(fluent, instance, true);
    }
    public ConfigMapListBuilder(ConfigMapListFluent<?> fluent,ConfigMapList instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withItems(instance.getItems()); 
            fluent.withKind(instance.getKind()); 
            fluent.withMetadata(instance.getMetadata()); 
            this.validationEnabled = validationEnabled; 
    }
    public ConfigMapListBuilder(ConfigMapList instance){
            this(instance,true);
    }
    public ConfigMapListBuilder(ConfigMapList instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.validationEnabled = validationEnabled; 
    }

    public ConfigMapList build(){
            ConfigMapList buildable = new ConfigMapList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ConfigMapListBuilder that = (ConfigMapListBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
